Adding negotiation of speech codecs between GSM and SIP when using rtp-bridge
[lcr.git] / message.h
index 4cfc5b1..ce6ed03 100644 (file)
--- a/message.h
+++ b/message.h
@@ -148,6 +148,14 @@ enum {
        B_MODE_HDLC,            /* hdlc data mode */
 };
 
+/* rtp-info structure */
+struct rtp_info {
+       int payloads;                   /* number of payloads offered */
+       unsigned char payload_types[32];/* rtp payload types */
+       unsigned int ip;                /* peer's IP */
+       unsigned short port;            /* peer's port */
+};
+
 /* call-info structure CALLER */
 struct caller_info {
        char id[32];                    /* id of caller (user number) */
@@ -191,6 +199,7 @@ struct connect_info {
        int screen;                     /* who provided the number */
        char display[84];               /* display information */
        char imsi[16];                  /* IMSI for gsm terminated calls */
+       struct rtp_info rtpinfo;        /* info about RTP peer */
 };
 
 /* call-info structure DISCONNECT */
@@ -240,6 +249,7 @@ struct notify_info {
 struct progress_info {
        int progress;                   /* progress indicator */
        int location;                   /* progress location */
+       struct rtp_info rtpinfo;        /* info about RTP peer */
 };
 
 /* call-info structure FACILITY */
@@ -266,7 +276,8 @@ struct message_setup {
        struct redir_info redirinfo;            /* info on redirection (to the calling user) */
        struct capa_info capainfo;              /* info on l2,l3 capability */
        struct useruser_info useruser;          /* user-user */
-//     struct progress_info progress;          /* info on call progress */
+       struct progress_info progress;          /* info on call progress */
+       struct rtp_info rtpinfo;                /* info about RTP peer */
        char context[128];                      /* asterisk context */
 };